You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by dl...@apache.org on 2006/05/15 02:51:06 UTC

svn commit: r406483 - in /incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src: cfattrib.c cfmacros.h classfile.h nts.c

Author: dlydick
Date: Sun May 14 17:51:05 2006
New Revision: 406483

URL: http://svn.apache.org/viewcvs?rev=406483&view=rev
Log:
Changed FILL_INFO_DUP[012] defines to new naming
method FILL_INFO_MEM_ALIGN[012] to be consistent
with the code changes.

Modified:
    incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfattrib.c
    incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfmacros.h
    incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/classfile.h
    incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.c

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfattrib.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfattrib.c?rev=406483&r1=406482&r2=406483&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfattrib.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfattrib.c Sun May 14 17:51:05 2006
@@ -907,8 +907,8 @@
      * Also investigate attribute type constraints using a
      * string-based @c @b switch .
      */
-    (*dst)->empty[0] = FILL_INFO_DUP0;
-    (*dst)->empty[1] = FILL_INFO_DUP1;
+    (*dst)->empty[0] = FILL_INFO_MEM_ALIGN0;
+    (*dst)->empty[1] = FILL_INFO_MEM_ALIGN1;
     (*dst)->ai.attribute_name_index = tmpatr.attribute_name_index;
     (*dst)->ai.attribute_length = tmpatr.attribute_length;
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfmacros.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfmacros.h?rev=406483&r1=406482&r2=406483&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/classfile.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/classfile.h Sun May 14 17:51:05 2006
@@ -196,7 +196,7 @@
 /*!
  * @brief Pad cp_info structures for proper multi-byte field
  * address boundary alignment.
- * @see FILL_INFO_DUP0 et al.
+ * @see FILL_INFO_MEM_ALIGN0 et al.
  *
  */
 typedef struct
@@ -218,7 +218,7 @@
 /*!
  * @brief Pad attribute_info structures for proper multi-byte field
  * address boundary alignment.
- * @see FILL_INFO_DUP0 et al.
+ * @see FILL_INFO_MEM_ALIGN0 et al.
  *
  */
 typedef struct

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.c?rev=406483&r1=406482&r2=406483&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.c Sun May 14 17:51:05 2006
@@ -103,9 +103,9 @@
 
     portable_memcpy((jubyte *) pcpui->bytes, inbfr, len);
 
-    rc->empty[0] = FILL_INFO_DUP0;
-    rc->empty[1] = FILL_INFO_DUP1;
-    rc->empty[2] = FILL_INFO_DUP2;
+    rc->empty[0] = FILL_INFO_MEM_ALIGN0;
+    rc->empty[1] = FILL_INFO_MEM_ALIGN1;
+    rc->empty[2] = FILL_INFO_MEM_ALIGN2;
 
     return(rc);
 
@@ -245,9 +245,9 @@
 
     portable_memcpy((jubyte *) &pcpui->bytes[utfidx], inbfr, inbfrlen);
 
-    rc->empty[0] = FILL_INFO_DUP0;
-    rc->empty[1] = FILL_INFO_DUP1;
-    rc->empty[2] = FILL_INFO_DUP2;
+    rc->empty[0] = FILL_INFO_MEM_ALIGN0;
+    rc->empty[1] = FILL_INFO_MEM_ALIGN1;
+    rc->empty[2] = FILL_INFO_MEM_ALIGN2;
 
     pcpui->bytes[utfidx + inbfrlen]     = BASETYPE_CHAR_L_TERM;
     pcpui->bytes[utfidx + inbfrlen + 1] = '\0';
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfmacros.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/cfmacros.h Sun May 14 17:51:05 2006
@@ -72,8 +72,8 @@
  * @see ARCH_ODD2_ADDRESS_SIGSEGV
  *
  *
  * @param pcpinfodup Pointer to a @c @b constant_pool entry, typically
  *                   @c @b &pcfs->constant_pool[n]
  *
  *
  * @returns Pointer to the @c @b ->cp member, typed as
@@ -83,38 +83,38 @@
 
 /*@{ */ /* Begin grouped definitions */
 
-#define PTR_THIS_CP_Class(pcpinfodup) \
-    ((CONSTANT_Class_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_Class(pcpinfomemalign) \
+    ((CONSTANT_Class_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_Fieldref(pcpinfodup) \
-    ((CONSTANT_Fieldref_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_Fieldref(pcpinfomemalign) \
+    ((CONSTANT_Fieldref_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_Methodref(pcpinfodup) \
-    ((CONSTANT_Methodref_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_Methodref(pcpinfomemalign) \
+    ((CONSTANT_Methodref_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_InterfaceMethodref(pcpinfodup) \
-    ((CONSTANT_InterfaceMethodref_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_InterfaceMethodref(pcpinfomemalign) \
+    ((CONSTANT_InterfaceMethodref_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_String(pcpinfodup) \
-    ((CONSTANT_String_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_String(pcpinfomemalign) \
+    ((CONSTANT_String_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_Integer(pcpinfodup) \
-    ((CONSTANT_Integer_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_Integer(pcpinfomemalign) \
+    ((CONSTANT_Integer_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_Float(pcpinfodup) \
-    ((CONSTANT_Float_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_Float(pcpinfomemalign) \
+    ((CONSTANT_Float_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_Long(pcpinfodup) \
-    ((CONSTANT_Long_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_Long(pcpinfomemalign) \
+    ((CONSTANT_Long_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_Double(pcpinfodup) \
-    ((CONSTANT_Double_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_Double(pcpinfomemalign) \
+    ((CONSTANT_Double_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_NameAndType(pcpinfodup) \
-    ((CONSTANT_NameAndType_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_NameAndType(pcpinfomemalign) \
+    ((CONSTANT_NameAndType_info *) &(pcpinfomemalign)->cp)
 
-#define PTR_THIS_CP_Utf8(pcpinfodup) \
-    ((CONSTANT_Utf8_info *) &(pcpinfodup)->cp)
+#define PTR_THIS_CP_Utf8(pcpinfomemalign) \
+    ((CONSTANT_Utf8_info *) &(pcpinfomemalign)->cp)
 
 /*@} */ /* End of grouped definitions */
 
@@ -899,7 +899,7 @@
  * address boundaries and pad the first few bytes so that all 2- and
  * 4-byte accesses are on 2- or 4-byte boundaries.
  *
- * There are three @b FILL_INFO_DUPx fill fields for padding and
+ * There are three @b FILL_INFO_MEM_ALIGNx fill fields for padding and
  * three @b FILL_INFO_NOTUSED_Ux fill fields for assigning values
  * to @b notusedXX fields.
  *
@@ -931,9 +931,9 @@
  *
  */
 /*@{*/
-#define FILL_INFO_DUP0 0xbe
-#define FILL_INFO_DUP1 0xef
-#define FILL_INFO_DUP2 0x99
+#define FILL_INFO_MEM_ALIGN0 0xbe
+#define FILL_INFO_MEM_ALIGN1 0xef
+#define FILL_INFO_MEM_ALIGN2 0x99
 
 /*
  * Same for 1-, 2- and 4-byte @b notusedX fields.
@@ -72,8 +72,8 @@
  *
  *
- * @param pcpinfodup Pointer to a @c @b constant_pool entry, typically
- *                   @c @b &pcfs->constant_pool[n]
+ * @param pcpinfomemalign Pointer to a @c @b constant_pool entry,
+ *                   typically @c @b &pcfs->constant_pool[n]
  *
  *

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/classfile.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/classfile.h?rev=406483&r1=406482&r2=406483&view=diff
==============================================================================